==> atf-0.5.tar.gz: atf-0.5/tests/atf/atf-sh/t_tp.sh <==
#
# Automated Testing Framework (atf)
#
# Copyright (c) 2007, 2008 The NetBSD Foundation, Inc.
# All rights reserved.
#
# Redistribution and use in source and binary forms, with or without
# modification, are permitted provided that the following conditions
# are met:
# 1. Redistributions of source code must retain the above copyright
#    notice, this list of conditions and the following disclaimer.
# 2. Redistributions in binary form must reproduce the above copyright
#    notice, this list of conditions and the following disclaimer in the
#    documentation and/or other materials provided with the distribution.
#
# THIS SOFTWARE IS PROVIDED BY THE NETBSD FOUNDATION, INC. AND
# CONTRIBUTORS ``AS IS'' AND ANY EXPRESS OR IMPLIED WARRANTIES,
# INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF
# MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED.
# IN NO EVENT SHALL THE FOUNDATION OR CONTRIBUTORS BE LIABLE FOR ANY
# DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL
# DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE
# GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS
# INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER
# IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR
# OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN
# IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
#

atf_test_case srcdir
srcdir_head()
{
    atf_set "descr" "Verifies that the source directory can be queried" \
                    "from the initialization function"
}
srcdir_body()
{
    mkdir work
    atf_check "cp $(atf_get_srcdir)/h_misc work" 0 null null
    cat >work/subrs <<EOF
helper_subr() {
    echo "This is a helper subroutine"
}
EOF

    atf_check "./work/h_misc -s $(pwd)/work tp_srcdir" 0 stdout null
    atf_check "grep 'Calling helper' stdout" 0 ignore null
    atf_check "grep 'This is a helper subroutine' stdout" 0 ignore null
}

atf_init_test_cases()
{
    atf_add_test_case srcdir
}

# vim: syntax=sh:expandtab:shiftwidth=4:softtabstop=4

==> atf-0.6.tar.gz: atf-0.6/tests/atf/atf-sh/t_tp.sh <==
#
# Automated Testing Framework (atf)
#
# Copyright (c) 2007, 2008 The NetBSD Foundation, Inc.
# All rights reserved.
#
# Redistribution and use in source and binary forms, with or without
# modification, are permitted provided that the following conditions
# are met:
# 1. Redistributions of source code must retain the above copyright
#    notice, this list of conditions and the following disclaimer.
# 2. Redistributions in binary form must reproduce the above copyright
#    notice, this list of conditions and the following disclaimer in the
#    documentation and/or other materials provided with the distribution.
#
# THIS SOFTWARE IS PROVIDED BY THE NETBSD FOUNDATION, INC. AND
# CONTRIBUTORS ``AS IS'' AND ANY EXPRESS OR IMPLIED WARRANTIES,
# INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF
# MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED.
# IN NO EVENT SHALL THE FOUNDATION OR CONTRIBUTORS BE LIABLE FOR ANY
# DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL
# DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE
# GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS
# INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER
# IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR
# OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN
# IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
#

atf_test_case srcdir
srcdir_head()
{
    atf_set "descr" "Verifies that the source directory can be queried" \
                    "from the initialization function"
}
srcdir_body()
{
    mkdir work
    atf_check -s eq:0 -o empty -e empty cp "$(atf_get_srcdir)/h_misc" work
    cat >work/subrs <<EOF
helper_subr() {
    echo "This is a helper subroutine"
}
EOF

    atf_check -s eq:0 -o save:stdout -e empty \
              ./work/h_misc -s "$(pwd)"/work tp_srcdir
    atf_check -s eq:0 -o ignore -e empty grep 'Calling helper' stdout
    atf_check -s eq:0 -o ignore -e empty \
              grep 'This is a helper subroutine' stdout
}

atf_init_test_cases()
{
    atf_add_test_case srcdir
}

# vim: syntax=sh:expandtab:shiftwidth=4:softtabstop=4
